@@ -1,5 +1,7 @@
 //! Collect constants used across ckb components.
 
+/// hardfork constant
+pub mod hardfork;
 /// store constant
 pub mod store;
 /// sync constant
